Skip to contents

Tutorial-ready Seurat spatial object generated from the provided raw 10x Human Lymph Node files.

Usage

aegis_example

Format

A Seurat object

10x Genomics Human Lymph Node Visium sample files distributed in this repository