Build and save example data from raw Human Lymph Node files
Source:R/data-build.R
build_aegis_example_data.RdBuild and save example data from raw Human Lymph Node files
Usage
build_aegis_example_data(
raw_dir = ".",
output_file = file.path("data", "aegis_example.rda"),
object_name = "aegis_example",
max_spots = 1200L,
seed = 42
)