R/data-doc.R
aegis_example.Rd
Tutorial-ready Seurat spatial object generated from the provided raw 10x Human Lymph Node files.
aegis_example
A Seurat object
10x Genomics Human Lymph Node Visium sample files distributed in this repository